@@ -1,12 +1,16 @@
-( cd usr/X11R7/lib ; rm -rf libGL.so.1 )
-( cd usr/X11R7/lib ; ln -sf libGL.so.1.2 libGL.so.1 )
-( cd usr/X11R7/lib ; rm -rf libGLw.so.1 )
-( cd usr/X11R7/lib ; ln -sf libGLw.so.1.0.0 libGLw.so.1 )
-( cd usr/X11R7/lib ; rm -rf libGLU.so.1 )
-( cd usr/X11R7/lib ; ln -sf libGLU.so.1.3.070401 libGLU.so.1 )
 ( cd usr/X11R7/lib ; rm -rf libGL.so )
 ( cd usr/X11R7/lib ; ln -sf libGL.so.1 libGL.so )
+( cd usr/X11R7/lib ; rm -rf libGL.so.1 )
+( cd usr/X11R7/lib ; ln -sf libGL.so.1.2 libGL.so.1 )
 ( cd usr/X11R7/lib ; rm -rf libGLU.so )
 ( cd usr/X11R7/lib ; ln -sf libGLU.so.1 libGLU.so )
+( cd usr/X11R7/lib ; rm -rf libGLU.so.1 )
+( cd usr/X11R7/lib ; ln -sf libGLU.so.1.3.070402 libGLU.so.1 )
 ( cd usr/X11R7/lib ; rm -rf libGLw.so )
 ( cd usr/X11R7/lib ; ln -sf libGLw.so.1 libGLw.so )
+( cd usr/X11R7/lib ; rm -rf libGLw.so.1 )
+( cd usr/X11R7/lib ; ln -sf libGLw.so.1.0.0 libGLw.so.1 )
+( cd usr/X11R7/lib ; rm -rf libglut.so )
+( cd usr/X11R7/lib ; ln -sf libglut.so.3 libglut.so )
+( cd usr/X11R7/lib ; rm -rf libglut.so.3 )
+( cd usr/X11R7/lib ; ln -sf libglut.so.3.7.1 libglut.so.3 )
